@@ -40,8 +40,8 @@ void Frame_Resizer_Base::init()
 
 	drawingarea .signal_realize() .connect( 
 			sigc::mem_fun(*this, &Frame_Resizer_Base::drawingarea_on_realize) ) ;
-	drawingarea .signal_expose_event() .connect( 
-			sigc::mem_fun(*this, &Frame_Resizer_Base::drawingarea_on_expose) ) ;
+	drawingarea.signal_draw().connect(
+			sigc::mem_fun(*this, &Frame_Resizer_Base::drawingarea_on_draw));
 	drawingarea .signal_motion_notify_event() .connect( 
 			sigc::mem_fun(*this, &Frame_Resizer_Base::drawingarea_on_mouse_motion) ) ;
 	drawingarea .signal_button_press_event() .connect( 
@@ -59,8 +59,8 @@ void Frame_Resizer_Base::init()
 	color_background.set("darkgrey");
 	color_arrow_rectangle.set("lightgrey");
 
-	cursor_resize = new Gdk::Cursor( Gdk::SB_H_DOUBLE_ARROW ) ; 
-	cursor_move   = new Gdk::Cursor( Gdk::FLEUR ) ; 
+	cursor_resize = Gdk::Cursor::create(Gdk::SB_H_DOUBLE_ARROW);
+	cursor_move   = Gdk::Cursor::create(Gdk::FLEUR);
 	  
 	GRIP_MOVE = GRIP_LEFT = GRIP_RIGHT = false;
 	X_END = 0;
@@ -74,12 +74,12 @@ void Frame_Resizer_Base::init()
 	this ->show_all_children();
 }
 
-void Frame_Resizer_Base::set_rgb_partition_color( const Gdk::Color & color )
+void Frame_Resizer_Base::set_rgb_partition_color(const Gdk::RGBA& color)
 {
 	this ->color_partition = color ;
 }
 
-void Frame_Resizer_Base::override_default_rgb_unused_color( const Gdk::Color & color ) 
+void Frame_Resizer_Base::override_default_rgb_unused_color(const Gdk::RGBA& color)
 {
 	this ->color_unused = color ;
 }
@@ -138,20 +138,8 @@ void Frame_Resizer_Base::drawingarea_on_realize()
 	drawingarea .add_events( Gdk::LEAVE_NOTIFY_MASK );
 }
 
-bool Frame_Resizer_Base::drawingarea_on_expose( GdkEventExpose * ev )
+bool Frame_Resizer_Base::drawingarea_on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
 {
-	Glib::RefPtr<Gdk::Window> window = drawingarea.get_window();
-	if (!window)
-		return true;
-
-	Cairo::RefPtr<Cairo::Context> cr = window->create_cairo_context();
-
-	// Clip to the area indicated by the expose event so that we only redraw
-	// the portion of the window that needs to be redrawn.
-	cr->rectangle(ev->area.x, ev->area.y,
-	              ev->area.width, ev->area.height);
-	cr->clip();
-
 	cr->set_line_cap(Cairo::LINE_CAP_SQUARE);
 	cr->set_line_width(1.0);
 
@@ -306,18 +294,18 @@ bool Frame_Resizer_Base::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 		     ev ->x <= X_START &&
 		     ev ->y >= 5 &&
 		     ev ->y <= 45 )
-			drawingarea .get_parent_window() ->set_cursor( *cursor_resize ) ;
+			drawingarea.get_parent_window()->set_cursor(cursor_resize);
 		//right grip
 		else if ( ev ->x >= X_END &&
 			  ev ->x <= X_END + GRIPPER &&
 			  ev ->y >= 5 && 
 			  ev ->y <= 45 )
-			drawingarea .get_parent_window() ->set_cursor( *cursor_resize ) ;
+			drawingarea.get_parent_window()->set_cursor(cursor_resize);
 		//move grip
 		else if ( ! fixed_start && 
 			  ev ->x >= X_START && 
 			  ev ->x <= X_END )
-			drawingarea .get_parent_window() ->set_cursor( *cursor_move ) ;
+			drawingarea.get_parent_window()->set_cursor(cursor_move);
 		//normal pointer 
 		else								
 			drawingarea .get_parent_window() ->set_cursor() ;		
@@ -378,29 +366,29 @@ void Frame_Resizer_Base::draw_partition(const Cairo::RefPtr<Cairo::Context>& cr)
 		UNUSED = 0 ;
 
 	// Background color
-	Gdk::Cairo::set_source_color(cr, color_background);
+	Gdk::Cairo::set_source_rgba(cr, color_background);
 	cr->rectangle(0, 0, 536, 50);
 	cr->fill();
 
 	// The two rectangles on each side of the partition
-	Gdk::Cairo::set_source_color(cr, color_arrow_rectangle);
+	Gdk::Cairo::set_source_rgba(cr, color_arrow_rectangle);
 	cr->rectangle(0, 0, 10, 50);
 	cr->fill();
 	cr->rectangle(526, 0, 10, 50);
 	cr->fill();
 
 	// Partition
-	Gdk::Cairo::set_source_color(cr, color_partition);
+	Gdk::Cairo::set_source_rgba(cr, color_partition);
 	cr->rectangle(X_START, 0, X_END - X_START, 50);
 	cr->fill();
 
 	// Used
-	Gdk::Cairo::set_source_color(cr, color_used);
+	Gdk::Cairo::set_source_rgba(cr, color_used);
 	cr->rectangle(X_START + BORDER, BORDER, USED, 34);
 	cr->fill();
 
 	// Unused
-	Gdk::Cairo::set_source_color(cr, color_unused);
+	Gdk::Cairo::set_source_rgba(cr, color_unused);
 	cr->rectangle(X_START + BORDER + USED, BORDER, UNUSED, 34);
 	cr->fill();
 
@@ -426,16 +414,16 @@ void Frame_Resizer_Base::draw_resize_grip(const Cairo::RefPtr<Cairo::Context>& c
 		arrow_points[ 1 ] .set_x( X_END + GRIPPER ) ; 
 		arrow_points[ 2 ] .set_x( X_END )  ;
 	}
-	
+
 	// Attach resize arrows to the partition
-	Gdk::Cairo::set_source_color(cr, color_arrow_rectangle);
+	Gdk::Cairo::set_source_rgba(cr, color_arrow_rectangle);
 	cr->rectangle((arrow_type == ARROW_LEFT ? X_START - GRIPPER : X_END + 1) + 0.5,
 	              5 + 0.5,
 	              9,
 	              40);
 	cr->stroke();
 
-	Gdk::Cairo::set_source_color(cr, color_arrow);
+	Gdk::Cairo::set_source_rgba(cr, color_arrow);
 	cr->move_to(arrow_points[0].get_x(), arrow_points[0].get_y());
 	cr->line_to(arrow_points[1].get_x(), arrow_points[1].get_y());
 	cr->line_to(arrow_points[2].get_x(), arrow_points[2].get_y());
@@ -451,8 +439,6 @@ void Frame_Resizer_Base::redraw()
 
 Frame_Resizer_Base::~Frame_Resizer_Base()
 {
-	delete cursor_resize;
-	delete cursor_move;
 }
 
 
