@@ -160,6 +160,11 @@ bool Proc_Partitions_Info::is_whole_disk_device_name(const Glib::ustring& name)
 	if (Utils::regexp_label(name, "^(bcache[0-9]+)$") != "")
 		return true;
 
+	// Match Network Block Device names.
+	// E.g.: device = nbd0 (partition = nbd0p1)
+	if (Utils::regexp_label(name, "^(nbd[0-9]+)$") != "")
+		return true;
+
 	return false;
 }
 
