@@ -31,11 +31,8 @@ FS hfs::get_filesystem_support()
 	FS fs( FS_HFS );
 
 	fs .busy = FS::GPARTED ;
-
-#ifdef HAVE_LIBPARTED_FS_RESIZE
 	fs.read = FS::LIBPARTED;
 	fs.shrink = FS::LIBPARTED;
-#endif
 
 	if ( ! Glib::find_program_in_path( "hformat" ) .empty() )
 	{
@@ -57,7 +54,7 @@ FS hfs::get_filesystem_support()
 
 bool hfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	Glib::ustring cmd = "";
+	Glib::ustring cmd;
 	if( new_partition.get_filesystem_label().empty() )
 		cmd = "hformat " + Glib::shell_quote( new_partition.get_path() );
 	else
