@@ -31,11 +31,8 @@ FS hfsplus::get_filesystem_support()
 	FS fs( FS_HFSPLUS );
 
 	fs .busy = FS::GPARTED ;
-
-#ifdef HAVE_LIBPARTED_FS_RESIZE
 	fs.read = FS::LIBPARTED;
 	fs.shrink = FS::LIBPARTED;
-#endif
 
 	if ( ! Glib::find_program_in_path( "mkfs.hfsplus" ) .empty() )
 	{
@@ -55,7 +52,7 @@ FS hfsplus::get_filesystem_support()
 
 bool hfsplus::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	Glib::ustring cmd = "";
+	Glib::ustring cmd;
 	if( new_partition.get_filesystem_label().empty() )
 		cmd = "mkfs.hfsplus " + Glib::shell_quote( new_partition.get_path() );
 	else
