@@ -64,13 +64,11 @@ FS lvm2_pv::get_filesystem_support()
 		fs .check  = FS::EXTERNAL ;
 		fs .remove = FS::EXTERNAL ;
 		fs .online_read = FS::EXTERNAL ;
-#ifdef ENABLE_ONLINE_RESIZE
 		if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
 		{
 			fs .online_grow = fs .grow ;
 			fs .online_shrink = fs.shrink ;
 		}
-#endif
 	}
 
 	return fs ;
@@ -105,7 +103,7 @@ bool lvm2_pv::create( const Partition & new_partition, OperationDetail & operati
 
 bool lvm2_pv::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
-	Glib::ustring size = "" ;
+	Glib::ustring size;
 	if ( ! fill_partition )
 		size = " --yes --setphysicalvolumesize " +
 		       Utils::num_to_str(partition_new.get_byte_length() / KIBIBYTE) + "K ";
