@@ -70,10 +70,8 @@ FS reiserfs::get_filesystem_support()
 	}
 
 	fs .online_read = FS::GPARTED ;
-#ifdef ENABLE_ONLINE_RESIZE
 	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
 		fs. online_grow = fs. grow ;
-#endif
 
 	//Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
 	fs_limits.min_size = 34 * MEBIBYTE;
@@ -176,7 +174,7 @@ bool reiserfs::create( const Partition & new_partition, OperationDetail & operat
 
 bool reiserfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 { 
-	Glib::ustring size = "" ;
+	Glib::ustring size;
 	if ( ! fill_partition )
 		size = " -s " + Utils::num_to_str(partition_new.get_byte_length());
 	const Glib::ustring resize_cmd = "echo y | resize_reiserfs" + size +
